@@ -3,7 +3,6 @@ from rift.types.addr import MsgAddress
 from rift.types.bases import Builder, Cell, Dict, Int, Slice, String
 from rift.types.bool import Bool
 from rift.types.coin import Coin
-from rift.types.constructor import Constructor
 from rift.types.contract_dep import ContractDeployer
 from rift.types.either import Either
 from rift.types.either_ref import EitherRef
@@ -22,5 +21,6 @@ from rift.types.msg import (
 )
 from rift.types.payload import Payload
 from rift.types.ref import Ref
+from rift.types.signed_payload import SignedPayload
 from rift.types.sized_int import integer
 from rift.types.slice import slice
